@@ -20,8 +20,9 @@ from __future__ import annotations
 
 import logging
 import warnings
+from collections.abc import Collection
 from functools import cached_property
-from typing import TYPE_CHECKING, Collection
+from typing import TYPE_CHECKING
 from urllib.parse import urlencode
 
 from google.cloud import logging as gcp_logging
@@ -29,13 +30,18 @@ from google.cloud.logging import Resource
 from google.cloud.logging.handlers.transports import BackgroundThreadTransport, Transport
 from google.cloud.logging_v2.services.logging_service_v2 import LoggingServiceV2Client
 from google.cloud.logging_v2.types import ListLogEntriesRequest, ListLogEntriesResponse
+from packaging.version import Version
 
+from airflow import __version__ as airflow_version
 from airflow.exceptions import RemovedInAirflow3Warning
 from airflow.providers.google.cloud.utils.credentials_provider import get_credentials_and_project_id
 from airflow.providers.google.common.consts import CLIENT_INFO
 from airflow.utils.log.trigger_handler import ctx_indiv_trigger
 from airflow.utils.types import NOTSET, ArgNotSet
 
+AIRFLOW_VERSION = Version(airflow_version)
+AIRFLOW_V_3_0_PLUS = Version(AIRFLOW_VERSION.base_version) >= Version("3.0.0")
+
 if TYPE_CHECKING:
     from google.auth.credentials import Credentials
 
@@ -82,7 +88,7 @@ class StackdriverTaskHandler(logging.Handler):
 
     LABEL_TASK_ID = "task_id"
     LABEL_DAG_ID = "dag_id"
-    LABEL_EXECUTION_DATE = "execution_date"
+    LABEL_LOGICAL_DATE = "logical_date" if AIRFLOW_V_3_0_PLUS else "execution_date"
     LABEL_TRY_NUMBER = "try_number"
     LOG_VIEWER_BASE_URL = "https://console.cloud.google.com/logs/viewer"
     LOG_NAME = "Google Stackdriver"
@@ -338,7 +344,9 @@ class StackdriverTaskHandler(logging.Handler):
         return {
             cls.LABEL_TASK_ID: ti.task_id,
             cls.LABEL_DAG_ID: ti.dag_id,
-            cls.LABEL_EXECUTION_DATE: str(ti.execution_date.isoformat()),
+            cls.LABEL_LOGICAL_DATE: str(ti.logical_date.isoformat())
+            if AIRFLOW_V_3_0_PLUS
+            else str(ti.execution_date.isoformat()),
             cls.LABEL_TRY_NUMBER: str(ti.try_number),
         }
 
