@@ -21,8 +21,9 @@ from __future__ import annotations
 
 import ast
 import warnings
+from collections.abc import Sequence
 from functools import cached_property
-from typing import TYPE_CHECKING, Sequence, Tuple, cast
+from typing import TYPE_CHECKING, cast
 
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.cloud.automl_v1beta1 import (
@@ -53,7 +54,7 @@ if TYPE_CHECKING:
 
     from airflow.utils.context import Context
 
-MetaData = Sequence[Tuple[str, str]]
+MetaData = Sequence[tuple[str, str]]
 
 
 def _raise_exception_for_deprecated_operator(
@@ -85,7 +86,7 @@ class AutoMLTrainModelOperator(GoogleCloudBaseOperator):
     :class:`airflow.providers.google.cloud.operators.vertex_ai.auto_ml.CreateAutoMLTabularTrainingJobOperator`,
     :class:`airflow.providers.google.cloud.operators.vertex_ai.auto_ml.CreateAutoMLVideoTrainingJobOperator`,
     :class:`airflow.providers.google.cloud.operators.vertex_ai.auto_ml.CreateAutoMLImageTrainingJobOperator`,
-    :class:`airflow.providers.google.cloud.operators.vertex_ai.auto_ml.CreateAutoMLTextTrainingJobOperator`,
+    :class:`airflow.providers.google.cloud.operators.vertex_ai.generative_model.SupervisedFineTuningTrainOperator`,
     instead.
 
     .. seealso::
@@ -155,7 +156,7 @@ class AutoMLTrainModelOperator(GoogleCloudBaseOperator):
                     "CreateAutoMLTabularTrainingJobOperator",
                     "CreateAutoMLVideoTrainingJobOperator",
                     "CreateAutoMLImageTrainingJobOperator",
-                    "CreateAutoMLTextTrainingJobOperator",
+                    "SupervisedFineTuningTrainOperator",
                 ],
             )
         hook = CloudAutoMLHook(
