@@ -20,8 +20,9 @@
 from __future__ import annotations
 
 import time
+from collections.abc import Sequence
 from functools import cached_property
-from typing import TYPE_CHECKING, Sequence
+from typing import TYPE_CHECKING
 
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.cloud.bigquery_datatransfer_v1 import (
@@ -37,6 +38,7 @@ from airflow.providers.google.cloud.hooks.bigquery_dts import BiqQueryDataTransf
 from airflow.providers.google.cloud.links.bigquery_dts import BigQueryDataTransferConfigLink
 from airflow.providers.google.cloud.operators.cloud_base import GoogleCloudBaseOperator
 from airflow.providers.google.cloud.triggers.bigquery_dts import BigQueryDataTransferRunTrigger
+from airflow.providers.google.common.hooks.base_google import PROVIDE_PROJECT_ID
 
 if TYPE_CHECKING:
     from google.api_core.retry import Retry
@@ -94,7 +96,7 @@ class BigQueryCreateDataTransferOperator(GoogleCloudBaseOperator):
         self,
         *,
         transfer_config: dict,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         location: str | None = None,
         authorization_code: str | None = None,
         retry: Retry | _MethodDefault = DEFAULT,
@@ -187,7 +189,7 @@ class BigQueryDeleteDataTransferConfigOperator(GoogleCloudBaseOperator):
         self,
         *,
         transfer_config_id: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         location: str | None = None,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
@@ -273,7 +275,7 @@ class BigQueryDataTransferServiceStartTransferRunsOperator(GoogleCloudBaseOperat
         self,
         *,
         transfer_config_id: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         location: str | None = None,
         requested_time_range: dict | None = None,
         requested_run_time: dict | None = None,
