@@ -19,7 +19,8 @@
 from __future__ import annotations
 
 import time
-from typing import TYPE_CHECKING, Any, Sequence
+from collections.abc import Sequence
+from typing import TYPE_CHECKING, Any
 
 from google.api_core.retry import exponential_sleep_generator
 from googleapiclient.errors import HttpError
