@@ -25,7 +25,8 @@ This module contains Google PubSub operators.
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Callable, Sequence
+from collections.abc import Sequence
+from typing import TYPE_CHECKING, Any, Callable
 
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.cloud.pubsub_v1.types import (
@@ -51,7 +52,8 @@ if TYPE_CHECKING:
 
 
 class PubSubCreateTopicOperator(GoogleCloudBaseOperator):
-    """Create a PubSub topic.
+    """
+    Create a PubSub topic.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -184,7 +186,8 @@ class PubSubCreateTopicOperator(GoogleCloudBaseOperator):
 
 
 class PubSubCreateSubscriptionOperator(GoogleCloudBaseOperator):
-    """Create a PubSub subscription.
+    """
+    Create a PubSub subscription.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -393,7 +396,8 @@ class PubSubCreateSubscriptionOperator(GoogleCloudBaseOperator):
 
 
 class PubSubDeleteTopicOperator(GoogleCloudBaseOperator):
-    """Delete a PubSub topic.
+    """
+    Delete a PubSub topic.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -491,7 +495,8 @@ class PubSubDeleteTopicOperator(GoogleCloudBaseOperator):
 
 
 class PubSubDeleteSubscriptionOperator(GoogleCloudBaseOperator):
-    """Delete a PubSub subscription.
+    """
+    Delete a PubSub subscription.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -591,7 +596,8 @@ class PubSubDeleteSubscriptionOperator(GoogleCloudBaseOperator):
 
 
 class PubSubPublishMessageOperator(GoogleCloudBaseOperator):
-    """Publish messages to a PubSub topic.
+    """
+    Publish messages to a PubSub topic.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
