@@ -19,9 +19,9 @@
 
 from __future__ import annotations
 
-import warnings
+from collections.abc import Sequence
 from functools import cached_property
-from typing import TYPE_CHECKING, Any, Sequence
+from typing import TYPE_CHECKING, Any
 
 from google.api_core.exceptions import NotFound
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
@@ -111,7 +111,6 @@ class CustomTrainingJobBaseOperator(GoogleCloudBaseOperator):
         predefined_split_column_name: str | None = None,
         timestamp_split_column_name: str | None = None,
         tensorboard: str | None = None,
-        sync=True,
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
@@ -168,18 +167,10 @@ class CustomTrainingJobBaseOperator(GoogleCloudBaseOperator):
         self.predefined_split_column_name = predefined_split_column_name
         self.timestamp_split_column_name = timestamp_split_column_name
         self.tensorboard = tensorboard
-        self.sync = sync
         # END Run param
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: Context) -> None:
-        warnings.warn(
-            "The 'sync' parameter is deprecated and will be removed after 01.10.2024.",
-            AirflowProviderDeprecationWarning,
-            stacklevel=2,
-        )
-
     def execute_complete(self, context: Context, event: dict[str, Any]) -> dict[str, Any] | None:
         if event["status"] == "error":
             raise AirflowException(event["message"])
@@ -532,8 +523,6 @@ class CreateCustomContainerTrainingJobOperator(CustomTrainingJobBaseOperator):
         self.poll_interval = poll_interval
 
     def execute(self, context: Context):
-        super().execute(context)
-
         self.parent_model = self.parent_model.split("@")[0] if self.parent_model else None
 
         if self.deferrable:
@@ -990,8 +979,6 @@ class CreateCustomPythonPackageTrainingJobOperator(CustomTrainingJobBaseOperator
         self.poll_interval = poll_interval
 
     def execute(self, context: Context):
-        super().execute(context)
-
         self.parent_model = self.parent_model.split("@")[0] if self.parent_model else None
 
         if self.deferrable:
@@ -1455,8 +1442,6 @@ class CreateCustomTrainingJobOperator(CustomTrainingJobBaseOperator):
         self.poll_interval = poll_interval
 
     def execute(self, context: Context):
-        super().execute(context)
-
         self.parent_model = self.parent_model.split("@")[0] if self.parent_model else None
 
         if self.deferrable:
