@@ -26,9 +26,10 @@ import json
 import logging
 import os
 import tempfile
+from collections.abc import Generator, Sequence
 from contextlib import ExitStack, contextmanager
 from subprocess import check_output
-from typing import TYPE_CHECKING, Any, Callable, Generator, Sequence, TypeVar, cast
+from typing import TYPE_CHECKING, Any, Callable, TypeVar, cast
 
 import google.auth
 import google.oauth2.service_account
@@ -197,12 +198,6 @@ class GoogleBaseHook(BaseHook):
     JSON data provided in the UI: Specify 'Keyfile JSON'.
 
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled. The usage of this parameter should be limited only to Google Workspace
-        (gsuite) and marketing platform operators and hooks. It is deprecated for usage by Google Cloud
-        and Firebase operators and hooks, as well as transfer operators in other providers that involve
-        Google cloud.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -279,12 +274,11 @@ class GoogleBaseHook(BaseHook):
     def __init__(
         self,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
+        **kwargs,
     ) -> None:
-        super().__init__()
+        super().__init__(**kwargs)
         self.gcp_conn_id = gcp_conn_id
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
         self.extras: dict = self.get_connection(self.gcp_conn_id).extra_dejson
         self._cached_credentials: Credentials | None = None
@@ -339,7 +333,6 @@ class GoogleBaseHook(BaseHook):
             key_secret_name=key_secret_name,
             key_secret_project_id=key_secret_project_id,
             scopes=self.scopes,
-            delegate_to=self.delegate_to,
             target_principal=target_principal,
             delegates=delegates,
             is_anonymous=is_anonymous,
